@@ -111,10 +111,10 @@ class TrackMeHandlerSplkReplicaTrackerAdmin_v2(trackme_rest_handler.RESTHandler)
 
                 # component
                 component = resp_dict["component"]
-                if not component in ("dsm", "dhm", "mhm", "flx", "fqm", "cim", "wlk"):
+                if not component in ("dsm", "dhm", "mhm", "flx", "fqm", "wlk"):
                     return {
                         "payload": {
-                            "response": f'Invalid component="{component}", valid options are: dsm|dhm|mhm|flx|cim|fqm|wlk'
+                            "response": f'Invalid component="{component}", valid options are: dsm|dhm|mhm|flx|fqm|wlk'
                         },
                         "status": 500,
                     }
@@ -160,7 +160,7 @@ class TrackMeHandlerSplkReplicaTrackerAdmin_v2(trackme_rest_handler.RESTHandler)
                     {
                         "tenant_id": "The tenant identifier",
                         "source_tenant_id": "The source tenant identifier",
-                        "component": "The component, valid options are: dsm | dhm | mhm | flx | fqm | cim | wlk",
+                        "component": "The component, valid options are: dsm | dhm | mhm | flx | fqm | wlk",
                         "root_constraint": "the tracker report root search constraint, to define search filters scoping the data set",
                         "owner": "Optional, the Splunk user owning the objects to be created, defaults to the owner set for the tenant",
                         "cron_schedule": "Optional, the cron schedule, defaults to every 5 minutes",
@@ -554,14 +554,18 @@ class TrackMeHandlerSplkReplicaTrackerAdmin_v2(trackme_rest_handler.RESTHandler)
             if not describe:
                 tenant_id = resp_dict["tenant_id"]
                 replica_trackers_list = resp_dict["replica_trackers_list"]
-                # Handle as a CSV list of keys
-                replica_trackers_list = replica_trackers_list.split(",")
+                # Handle as a CSV list of keys, it not already a list
+                if not isinstance(replica_trackers_list, list):
+                    replica_trackers_list = [x.strip() for x in replica_trackers_list.split(",") if x.strip()]
+                else:
+                    # Filter out empty strings from existing list
+                    replica_trackers_list = [x.strip() if isinstance(x, str) else x for x in replica_trackers_list if (x.strip() if isinstance(x, str) else bool(x))]
                 # get component
                 component = resp_dict["component"]
-                if not component in ("dsm", "dhm", "mhm", "flx", "fqm", "cim", "wlk"):
+                if not component in ("dsm", "dhm", "mhm", "flx", "fqm", "wlk"):
                     return {
                         "payload": {
-                            "response": f'Invalid component="{component}", valid options are: dsm|dhm|mhm|flx|cim|fqm|wlk'
+                            "response": f'Invalid component="{component}", valid options are: dsm|dhm|mhm|flx|fqm|wlk'
                         },
                         "status": 500,
                     }
