@@ -41,7 +41,7 @@ logging.getLogger().setLevel(logger.level)
 import trackme_rest_handler
 
 # import trackme libs
-from trackme_libs import trackme_getloglevel, trackme_reqinfo, trackme_vtenant_account
+from trackme_libs import trackme_getloglevel, trackme_reqinfo, trackme_vtenant_account, trackme_get_version
 
 # import trackme load libs
 from trackme_libs_load import trackmeload
@@ -129,14 +129,7 @@ class TrackMeHandlerVtenantsRead_v2(trackme_rest_handler.RESTHandler):
             collection = service.kvstore[collection_name]
 
             # TrackMe version
-            trackme_version = None
-            app_confs = service.confs["app"]
-
-            for stanza in app_confs:
-                if stanza.name == "id":
-                    for stanzakey, stanzavalue in stanza.content.items():
-                        if stanzakey == "version":
-                            trackme_version = stanzavalue
+            trackme_version = trackme_get_version(service)
 
             # Get schema_version_required
             schema_version_required = trackme_schema_format_version(trackme_version)
@@ -149,10 +142,22 @@ class TrackMeHandlerVtenantsRead_v2(trackme_rest_handler.RESTHandler):
                 record["schema_version_required"] = schema_version_required
                 # Set the status of tenant_updated_status, if schema_version in the record is equal to schema_version_required,
                 # the status is "updated", otherwise it is "pending"
-                if int(record.get("schema_version")) == schema_version_required:
+                # If schema_version_required is 0 (version retrieval failed), treat all tenants as "updated"
+                # to align with graceful degradation when DB Connect causes permission issues
+                if schema_version_required == 0:
                     record["tenant_updated_status"] = "updated"
                 else:
-                    record["tenant_updated_status"] = "pending"
+                    # Handle case where schema_version is missing from the record (e.g., tenant created when version retrieval failed)
+                    schema_version = record.get("schema_version")
+                    if schema_version is None:
+                        # If schema_version is missing, use "undetermined" to indicate we cannot determine the status
+                        # This is different from "pending" which implies an upgrade is in progress
+                        # "undetermined" should not block underlying logic like hybrid trackers
+                        record["tenant_updated_status"] = "undetermined"
+                    elif int(schema_version) == schema_version_required:
+                        record["tenant_updated_status"] = "updated"
+                    else:
+                        record["tenant_updated_status"] = "pending"
 
                 schema_version_mtime = record.get("schema_version_mtime")
                 if schema_version_mtime:
@@ -242,6 +247,12 @@ class TrackMeHandlerVtenantsRead_v2(trackme_rest_handler.RESTHandler):
             "Content-Type": "application/json",
         }
 
+        # TrackMe reqinfo
+        reqinfo = trackme_reqinfo(
+            request_info.system_authtoken, request_info.server_rest_uri
+        )
+        trackmeconf = reqinfo["trackme_conf"]
+
         # get current user
         username = request_info.user
 
@@ -364,6 +375,9 @@ class TrackMeHandlerVtenantsRead_v2(trackme_rest_handler.RESTHandler):
             f"function post_trackmeload has terminated, run_time={round(time.time() - start, 3)}"
         )
 
+        # add trackmeconf to the response
+        final_response["trackmeconf"] = trackmeconf
+
         # Return
         return {
             "payload": final_response,
@@ -436,6 +450,12 @@ class TrackMeHandlerVtenantsRead_v2(trackme_rest_handler.RESTHandler):
             "Content-Type": "application/json",
         }
 
+        # TrackMe reqinfo
+        reqinfo = trackme_reqinfo(
+            request_info.system_authtoken, request_info.server_rest_uri
+        )
+        trackmeconf = reqinfo["trackme_conf"]
+
         # get current user
         username = request_info.user
 
@@ -549,6 +569,9 @@ class TrackMeHandlerVtenantsRead_v2(trackme_rest_handler.RESTHandler):
         # update the final response
         final_response["tenants_json"] = {"tenants": virtual_tenants_list}
 
+        # add trackmeconf to the response
+        final_response["trackmeconf"] = trackmeconf
+
         # log perf only in debug
         logger.debug(
             f"function post_trackmeload_legacy has terminated, run_time={round(time.time() - start, 3)}"
